@@ -1,9 +1,11 @@
 from .QPythonCompleter import QPythonCompleter
 from .QCXXCompleter import QCXXCompleter
 from .QLuaCompleter import QLuaCompleter
+from .QGLSLCompleter import QGLSLCompleter
 
 __all__ = [
     "QPythonCompleter",
     "QCXXCompleter",
     "QLuaCompleter",
+    "QGLSLCompleter",
 ]
